%define major			0
%define libmpfi			%mklibname %{name} %{major}
%define libmpfi_devel		%mklibname %{name} -d
%define libmpfi_static_devel	%mklibname %{name} -d -s

Name:		mpfi
Group:		Sciences/Mathematics
License:	LGPL
Summary:	Interval arithmetic multi-precision based on GMP and MPFR
Version:	1.5.4
Release:	%mkrel 2
Source:		https://perso.ens-lyon.fr/nathalie.revol/softwares/%{name}-%{version}.tar.xz
URL:		https://perso.ens-lyon.fr/nathalie.revol/software.html
# Fix possible use of initialized variables
Patch0:		%{name}-uninit.patch
# Fix mismatched type declarations
Patch1:		%{name}-mismatched-type.patch
# Fix incorrect use of the address-of operator
Patch2:		%{name}-bad-ref.patch
# Fix a missing #include in a test file
Patch3:		%{name}-test.patch

BuildRequires:	gmp-devel
BuildRequires:	pkgconfig(mpfr)

%description
MPFI is a C library for interval arithmetic multi-precision based on
the GMP and MPFR libraries.

%package	-n %{libmpfi}
Summary:	lib%{name} dynamic library
Group:		System/Libraries
Provides:	lib%{name} = %{version}-%{release}

%description	-n %{libmpfi}
lib%{name} dynamic library. MPFI is a C library for interval
arithmetic multi-precision based on the GMP and MPFR libraries.

%package	-n %{libmpfi_devel}
Summary:	lib%{name} libraries, includes, etc
Group:		Development/C
Provides:	%{name}-devel = %{version}-%{release}
Requires:	%{libmpfi} = %{version}-%{release}

%description	-n %{libmpfi_devel}
lib%{name} libraries, includes, etc. MPFI is a C library for interval
arithmetic multi-precision based on the GMP and MPFR libraries.

%package	-n %{libmpfi_static_devel}
Summary:	lib%{name} static libraries
Group:		Development/C
Provides:	%{name}-static-devel = %{version}-%{release}

%description	-n %{libmpfi_static_devel}
lib%{name} static libraries. MPFI is a C library for interval
arithmetic multi-precision based on the GMP and MPFR libraries.

%prep
%setup -q

# In the 1.5.4 release, these two tests try to call functions with mismatched
# signatures, then segfault.  It is not clear to me how to fix them.
sed -i 's/ tdiv_ext\$(EXEEXT)//;s/ trec_sqrt\$(EXEEXT)//' tests/Makefile.in

# In the 1.5.4 release, the data file needed by this test is missing.
sed -i 's/texp10\$(EXEEXT) //' tests/Makefile.in

%ifarch %{arm}
# In the 1.5.4 release, this test fails on 32-bit ARM for unknown reasons.
# Remove this when F36 reaches EOL (i.e., when 32-bit ARM is completely gone).
sed -i 's/ tset_ld\$(EXEEXT)//' tests/Makefile.in
%endif

%build
export CFLAGS="%{optflags} -fPIC"
%configure
%make_build

%install
%make_install

# Remove license files from doc
rm -f %{buildroot}%{_docdir}/mpfi/*

# Fix the pkgconfig file
sed -i 's/ -lmpfr -lgmp//;/Libs/aLibs.private: -lmpfr -lgmp' \
    %{buildroot}%{_libdir}/pkgconfig/mpfi.pc

%files -n %{libmpfi}
%{_libdir}/*.so.%{major}
%{_libdir}/*.so.%{major}.*

%files -n %{libmpfi_devel}
%{_includedir}/*
%{_libdir}/*.so
%{_infodir}/*
%{_libdir}/pkgconfig/mpfi.pc

%files -n %{libmpfi_static_devel}
%{_libdir}/*.a


%changelog
* Sat Jun 28 2025 umeabot <umeabot> 1.5.4-2.mga10
+ Revision: 2215211
- Mageia 10 Mass Rebuild

* Wed Sep 21 2022 luigiwalser <luigiwalser> 1.5.4-1.mga9
+ Revision: 1891036
- 1.5.4
- add post-release upstream patches via fedora
- add fixes for test suite and pkgconfig file from fedora

* Sat Mar 19 2022 umeabot <umeabot> 1.5.3-6.mga9
+ Revision: 1799398
- Mageia 9 Mass Rebuild

* Tue Mar 08 2022 mrambo3501 <mrambo3501> 1.5.3-5.mga9
+ Revision: 1789941
- fix files list

* Thu Feb 13 2020 umeabot <umeabot> 1.5.3-4.mga8
+ Revision: 1515243
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sun Sep 23 2018 umeabot <umeabot> 1.5.3-3.mga7
+ Revision: 1299621
- Mageia 7 Mass Rebuild
+ kekepower <kekepower>
- Use new make macros

* Mon Feb 19 2018 kekepower <kekepower> 1.5.3-2.mga7
+ Revision: 1203255
- Update to version 1.5.3
- Update to version 1.5.3

* Mon Feb 08 2016 umeabot <umeabot> 1.5.1-6.mga6
+ Revision: 944119
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 1.5.1-5.mga5
+ Revision: 749177
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 1.5.1-4.mga5
+ Revision: 727357
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 1.5.1-3.mga5
+ Revision: 682641
- Mageia 5 Mass Rebuild

* Mon Oct 21 2013 umeabot <umeabot> 1.5.1-2.mga4
+ Revision: 537836
- Mageia 4 Mass Rebuild

* Fri Sep 27 2013 sander85 <sander85> 1.5.1-1.mga4
+ Revision: 487923
- New version: 1.5.1

* Sat Jan 12 2013 umeabot <umeabot> 1.5-3.mga3
+ Revision: 360412
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Jun 10 2012 blino <blino> 1.5-2.mga3
+ Revision: 259542
- rebuild to get info pages as xz instead of lzma

* Mon Jan 31 2011 dmorgan <dmorgan> 1.5-1.mga1
+ Revision: 45322
- imported package mpfi


* Mon Jan 31 2011 Funda Wang <fwang@mandriva.org> 1.5-1mdv2011.0
+ Revision: 634340
- new version 1.5

  + Oden Eriksson <oeriksson@mandriva.com>
    - the mass rebuild of 2010.1 packages

* Wed Sep 09 2009 Paulo Andrade <pcpa@mandriva.com.br> 1.4-4mdv2010.0
+ Revision: 436127
+ rebuild (emptylog)

* Wed Sep 09 2009 Paulo Andrade <pcpa@mandriva.com.br> 1.4-3mdv2010.0
+ Revision: 435719
- Split package in dynamic, devel and static libraries

* Mon Aug 31 2009 Paulo Andrade <pcpa@mandriva.com.br> 1.4-2mdv2010.0
+ Revision: 423025
+ rebuild (emptylog)

* Tue Aug 25 2009 Paulo Andrade <pcpa@mandriva.com.br> 1.4-1mdv2010.0
+ Revision: 420682
- update to latest upstream release version 1.4.

* Wed May 20 2009 Paulo Andrade <pcpa@mandriva.com.br> 1.3.4-3mdv2010.0
+ Revision: 377882
+ rebuild (emptylog)

* Fri May 08 2009 Paulo Andrade <pcpa@mandriva.com.br> 1.3.4-2mdv2010.0
+ Revision: 373561
+ rebuild (emptylog)

* Thu Mar 26 2009 Paulo Andrade <pcpa@mandriva.com.br> 1.3.4-1mdv2009.1
+ Revision: 361479
- Initial import of mpfi, version 1.3.4, rc3.
  MPFI is a C library for interval arithmetic multi-precision based on
  the GMP and MPFR libraries.
  http://gforge.inria.fr/projects/mpfi/
- mpfi

